@@ -37,14 +37,8 @@ class NN():
 
         Typical usage example:
 
-        feature_extractor -> keras.model (pretrained or from scratch) /
-                             final output_layer should have fixed
-                             spatial resolution:
-                                (grid_size, grid_size, num_channels)
-                             but num_channels can vary.
-
     Attributes:
-        backbone (keras.model): Basic nn feature extractor.
+        model (keras.model): Neural net (hypothesis set).
         optimizer(keras.optimizers): Learning algorithm instance.
         init_timestamp (str): Acts as a unique folder identifier.
         logdir (str): Top level logdir.
@@ -54,12 +48,12 @@ class NN():
         checkpoint (tf.train.Checkpoint): Groups trackable objects, saving and
             restoring them.
     """
-    def __init__(self, backbone):
+    def __init__(self, model):
         """ Inits a standard backbone model.
         Args:
-            backbone (keras.model): Basic nn feature extractor.
+            model (keras.model): Neural net (hypothesis set).
         """
-        self.backbone = backbone
+        self.model = model
         self.loss = None
         self.loss_objective = None
         self.optimizer = None
@@ -149,11 +143,11 @@ class NN():
 
     def summary(self):
         """Returns a keras model summary on it underlying yolo model."""
-        return self.backbone.summary()
+        return self.model.summary()
 
     def predict(self, img):
         """Standard prediciton."""
-        return self.backbone.predict(img)
+        return self.model.predict(img)
 
     def compile(self, loss="l2", optimizer="adam", lr=1e-4,
                 loss_scaling=False):
@@ -169,10 +163,12 @@ class NN():
             - mssim_l2 = mssim + l2
 
         Args:
+            loss (keras.losses): Lossfunction for specific task. Defaults to l2.
             optimizer (str, optional): Optimizer. Defaults to "adam".
-            lr_gen (Float, optional): Learning rate generator. Defaults to 1e4.
-            lr_disc (Float, optional): Learning rate discriminator.
-                Defaults to 1e4.
+            lr (Float, optional): Learning rate. Defaults to 1e4.
+            loss_scaling (boolean, optional): Loss scaling for mixed presicion.
+                Defaults to False.
+
         """
         self.loss = loss
 
@@ -210,7 +206,7 @@ class NN():
 
         if self.checkpoint is None:
             self.checkpoint = tf.train.Checkpoint(optimizer=self.optimizer,
-                                                  model=self.backbone)
+                                                  model=self.model)
             self.ckpt_manager = tf.train.CheckpointManager(self.checkpoint,
                                                            self.ckpt_dir,
                                                            max_to_keep=5)
@@ -368,9 +364,9 @@ class NN():
             os.makedirs(model_dir)
 
         if model_format == "hdf5":
-            self.backbone.save(os.path.join(model_dir, "backbone.h5"))
+            self.model.save(os.path.join(model_dir, "backbone.h5"))
         elif model_format == "SavedModel":
-            self.backbone.save(os.path.join(model_dir, "backbone"))
+            self.model.save(os.path.join(model_dir, "backbone"))
 
     @tf.function
     def train_step(self, images, labels, batch_size, step):
@@ -392,7 +388,7 @@ class NN():
         with tf.GradientTape() as tape:
             # Predict
             start_time = time.time()
-            prediction = self.backbone(images, training=True)
+            prediction = self.model(images, training=True)
             end_time = time.time()
             img_per_second = (end_time - start_time) / batch_size
             tf.summary.scalar("inference_time[s]", img_per_second, step=step)
@@ -401,11 +397,11 @@ class NN():
             loss = self.loss_objective(labels, prediction)
 
         # Calculate gradient.
-        gradient = tape.gradient(loss, self.backbone.trainable_variables)
+        gradient = tape.gradient(loss, self.model.trainable_variables)
 
         # Apply gradient to weights.
         self.optimizer.apply_gradients(
-            zip(gradient, self.backbone.trainable_variables))
+            zip(gradient, self.model.trainable_variables))
 
         return prediction, loss
 
@@ -421,7 +417,7 @@ class NN():
         Returns:
             loss: Loss objective value (specified in __init__()).
         """
-        prediction = self.backbone(images, training=False)
+        prediction = self.model(images, training=False)
         loss = self.loss_objective(labels, prediction)
         return loss, prediction
 
